==> ice-3.7.5.tgz: package/src/es5/IceGrid/Registry.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.5
//
// <auto-generated>
//
// Generated from file `Registry.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/EnumBase", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/Locator"]).Ice;

  var IceGrid = _ModuleRegistry.require(module, ["../IceGrid/Exception", "../IceGrid/Session", "../IceGrid/Admin"]).IceGrid;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * Determines which load sampling interval to use.
   *
   **/

  IceGrid.LoadSample = Slice.defineEnum([['LoadSample1', 0], ['LoadSample5', 1], ['LoadSample15', 2]]);
  var iceC_IceGrid_Query_ids = ["::Ice::Object", "::IceGrid::Query"];
  /**
   * The IceGrid query interface. This interface is accessible to
   * Ice clients who wish to look up well-known objects.
   *
   **/

  IceGrid.Query = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class, _Ice$Object);

    var _super = _createSuper(_class);

    function _class() {
      _classCallCheck(this, _class);

      return _super.apply(this, arguments);
    }

    return _class;
  }(Ice.Object);

  IceGrid.QueryPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class2, _Ice$ObjectPrx);

    var _super2 = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super2.apply(this, arguments);
    }

    return _class2;
  }(Ice.ObjectPrx);

  Slice.defineOperations(IceGrid.Query, IceGrid.QueryPrx, iceC_IceGrid_Query_ids, 1, {
    "findObjectById": [, 2, 1,, [9], [[Ice.Identity]],,,,],
    "findObjectByType": [, 2, 1,, [9], [[7]],,,,],
    "findObjectByTypeOnLeastLoadedNode": [, 2, 1,, [9], [[7], [IceGrid.LoadSample._helper]],,,,],
    "findAllObjectsByType": [, 2, 1,, ["Ice.ObjectProxySeqHelper"], [[7]],,,,],
    "findAllReplicas": [, 2, 2,, ["Ice.ObjectProxySeqHelper"], [[9]],,,,]
  });
  var iceC_IceGrid_Registry_ids = ["::Ice::Object", "::IceGrid::Registry"];
  /**
   * The IceGrid registry allows clients create sessions
   * directly with the registry.
   *
   * @see Session
   * @see AdminSession
   *
   **/

  IceGrid.Registry = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class3, _Ice$Object2);

    var _super3 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super3.apply(this, arguments);
    }

    return _class3;
  }(Ice.Object);

  IceGrid.RegistryPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class4, _Ice$ObjectPrx2);

    var _super4 = _createSuper(_class4);

    function _class4() {
      _classCallCheck(this, _class4);

      return _super4.apply(this, arguments);
    }

    return _class4;
  }(Ice.ObjectPrx);

  Slice.defineOperations(IceGrid.Registry, IceGrid.RegistryPrx, iceC_IceGrid_Registry_ids, 1, {
    "createSession": [,,,, ["IceGrid.SessionPrx"], [[7], [7]],, [IceGrid.PermissionDeniedException],,],
    "createAdminSession": [,,,, ["IceGrid.AdminSessionPrx"], [[7], [7]],, [IceGrid.PermissionDeniedException],,],
    "createSessionFromSecureConnection": [,,,, ["IceGrid.SessionPrx"],,, [IceGrid.PermissionDeniedException],,],
    "createAdminSessionFromSecureConnection": [,,,, ["IceGrid.AdminSessionPrx"],,, [IceGrid.PermissionDeniedException],,],
    "getSessionTimeout": [, 2, 1,, [3],,,,,],
    "getACMTimeout": [, 2, 1,, [3],,,,,]
  });
  var iceC_IceGrid_Locator_ids = ["::Ice::Locator", "::Ice::Object", "::IceGrid::Locator"];
  /**
   * The IceGrid locator interface provides access to the {@link Query}
   * and {@link Registry} object of the IceGrid registry.
   *
   * @see Query
   * @see Registry
   *
   **/

  IceGrid.Locator = /*#__PURE__*/function (_Ice$Object3) {
    _inherits(_class5, _Ice$Object3);

    var _super5 = _createSuper(_class5);

    function _class5() {
      _classCallCheck(this, _class5);

      return _super5.apply(this, arguments);
    }

    _createClass(_class5, null, [{
      key: "_iceImplements",
      get: function get() {
        return [Ice.Locator];
      }
    }]);

    return _class5;
  }(Ice.Object);

  IceGrid.LocatorPrx = /*#__PURE__*/function (_Ice$ObjectPrx3) {
    _inherits(_class6, _Ice$ObjectPrx3);

    var _super6 = _createSuper(_class6);

    function _class6() {
      _classCallCheck(this, _class6);

      return _super6.apply(this, arguments);
    }

    _createClass(_class6, null, [{
      key: "_implements",
      get: function get() {
        return [Ice.LocatorPrx];
      }
    }]);

    return _class6;
  }(Ice.ObjectPrx);

  Slice.defineOperations(IceGrid.Locator, IceGrid.LocatorPrx, iceC_IceGrid_Locator_ids, 2, {
    "getLocalRegistry": [, 2, 2,, ["IceGrid.RegistryPrx"],,,,,],
    "getLocalQuery": [, 2, 2,, ["IceGrid.QueryPrx"],,,,,]
  });
  /* slice2js browser-bundle-skip */

  exports.IceGrid = IceGrid;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */

==> ice-3.7.70.tgz: package/src/es5/IceGrid/Registry.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.7
//
// <auto-generated>
//
// Generated from file `Registry.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/EnumBase", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/Locator"]).Ice;

  var IceGrid = _ModuleRegistry.require(module, ["../IceGrid/Exception", "../IceGrid/Session", "../IceGrid/Admin"]).IceGrid;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * Determines which load sampling interval to use.
   *
   **/

  IceGrid.LoadSample = Slice.defineEnum([['LoadSample1', 0], ['LoadSample5', 1], ['LoadSample15', 2]]);
  var iceC_IceGrid_Query_ids = ["::Ice::Object", "::IceGrid::Query"];
  /**
   * The IceGrid query interface. This interface is accessible to
   * Ice clients who wish to look up well-known objects.
   *
   **/

  IceGrid.Query = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class, _Ice$Object);

    var _super = _createSuper(_class);

    function _class() {
      _classCallCheck(this, _class);

      return _super.apply(this, arguments);
    }

    return _class;
  }(Ice.Object);

  IceGrid.QueryPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class2, _Ice$ObjectPrx);

    var _super2 = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super2.apply(this, arguments);
    }

    return _class2;
  }(Ice.ObjectPrx);

  Slice.defineOperations(IceGrid.Query, IceGrid.QueryPrx, iceC_IceGrid_Query_ids, 1, {
    "findObjectById": [, 2, 1,, [9], [[Ice.Identity]],,,,],
    "findObjectByType": [, 2, 1,, [9], [[7]],,,,],
    "findObjectByTypeOnLeastLoadedNode": [, 2, 1,, [9], [[7], [IceGrid.LoadSample._helper]],,,,],
    "findAllObjectsByType": [, 2, 1,, ["Ice.ObjectProxySeqHelper"], [[7]],,,,],
    "findAllReplicas": [, 2, 2,, ["Ice.ObjectProxySeqHelper"], [[9]],,,,]
  });
  var iceC_IceGrid_Registry_ids = ["::Ice::Object", "::IceGrid::Registry"];
  /**
   * The IceGrid registry allows clients create sessions
   * directly with the registry.
   *
   * @see Session
   * @see AdminSession
   *
   **/

  IceGrid.Registry = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class3, _Ice$Object2);

    var _super3 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super3.apply(this, arguments);
    }

    return _class3;
  }(Ice.Object);

  IceGrid.RegistryPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class4, _Ice$ObjectPrx2);

    var _super4 = _createSuper(_class4);

    function _class4() {
      _classCallCheck(this, _class4);

      return _super4.apply(this, arguments);
    }

    return _class4;
  }(Ice.ObjectPrx);

  Slice.defineOperations(IceGrid.Registry, IceGrid.RegistryPrx, iceC_IceGrid_Registry_ids, 1, {
    "createSession": [,,,, ["IceGrid.SessionPrx"], [[7], [7]],, [IceGrid.PermissionDeniedException],,],
    "createAdminSession": [,,,, ["IceGrid.AdminSessionPrx"], [[7], [7]],, [IceGrid.PermissionDeniedException],,],
    "createSessionFromSecureConnection": [,,,, ["IceGrid.SessionPrx"],,, [IceGrid.PermissionDeniedException],,],
    "createAdminSessionFromSecureConnection": [,,,, ["IceGrid.AdminSessionPrx"],,, [IceGrid.PermissionDeniedException],,],
    "getSessionTimeout": [, 2, 1,, [3],,,,,],
    "getACMTimeout": [, 2, 1,, [3],,,,,]
  });
  var iceC_IceGrid_Locator_ids = ["::Ice::Locator", "::Ice::Object", "::IceGrid::Locator"];
  /**
   * The IceGrid locator interface provides access to the {@link Query}
   * and {@link Registry} object of the IceGrid registry.
   *
   * @see Query
   * @see Registry
   *
   **/

  IceGrid.Locator = /*#__PURE__*/function (_Ice$Object3) {
    _inherits(_class5, _Ice$Object3);

    var _super5 = _createSuper(_class5);

    function _class5() {
      _classCallCheck(this, _class5);

      return _super5.apply(this, arguments);
    }

    _createClass(_class5, null, [{
      key: "_iceImplements",
      get: function get() {
        return [Ice.Locator];
      }
    }]);

    return _class5;
  }(Ice.Object);

  IceGrid.LocatorPrx = /*#__PURE__*/function (_Ice$ObjectPrx3) {
    _inherits(_class6, _Ice$ObjectPrx3);

    var _super6 = _createSuper(_class6);

    function _class6() {
      _classCallCheck(this, _class6);

      return _super6.apply(this, arguments);
    }

    _createClass(_class6, null, [{
      key: "_implements",
      get: function get() {
        return [Ice.LocatorPrx];
      }
    }]);

    return _class6;
  }(Ice.ObjectPrx);

  Slice.defineOperations(IceGrid.Locator, IceGrid.LocatorPrx, iceC_IceGrid_Locator_ids, 2, {
    "getLocalRegistry": [, 2, 2,, ["IceGrid.RegistryPrx"],,,,,],
    "getLocalQuery": [, 2, 2,, ["IceGrid.QueryPrx"],,,,,]
  });
  /* slice2js browser-bundle-skip */

  exports.IceGrid = IceGrid;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */
